'=======================================================================================================================================
'Publish Mobile Cert.vbs
'Jeff Guillet
'02/10/2010
'
'This script publishes the mobile user certificate into Active Directory for all members of the ActiveSync Users security group
'
'Micosoft link for CAPICOM: http://www.microsoft.com/downloads/details.aspx?displaylang=en&FamilyID=860EE43A-A843-462F-ABB5-FF88EA5896F6
'=======================================================================================================================================
 
On Error Resume Next
 
'Configure constants
Const ADS_PROPERTY_UPDATE = 2
Const ADS_PROPERTY_APPEND = 3
 
'--------------------------------------------------------------------------
'Modify the three variables below, as required
'--------------------------------------------------------------------------
eASUsersGroup = "ActiveSync Users"
pathToFiles = "\\fileserver\iPhone\"
certFile = "ActiveSyncUser.cer"
'--------------------------------------------------------------------------
 
msg = "This script publishes the '" & certFile & "' certificate to all members of" & vbCRLF
msg = msg & "the '" & eASUsersGroup & "' security group.  Do you want to continue?"
r = MsgBox(msg, vbYesNo + vbQuestion, "Publish Mobile Cert")
If r = vbNo then Wscript.Quit
 
'Create log file
Set fso = CreateObject("Scripting.FileSystemObject")
Set FullLog = fso.OpenTextFile(pathToFiles & "Publish Mobile Cert.log", 8, True)
 
'Check for and set dependencies
'--Check for CAPICOM.DLL
Set FSO = CreateObject("Scripting.FileSystemObject")
If NOT FSO.FileExists ("C:\Windows\System32\capicom.dll") Then
       If NOT FSO.FileExists (pathToFiles & "capicom.dll") Then
              MsgBox pathToFiles & "capicom.dll is missing. Cannot continue.", vbCritical, "Missing File"
              Wscript.Quit
       Else
              FSO.CopyFile pathToFiles & "capicom.dll", "C:\Windows\System32\"
       End if
End if
'--Check for certificate
If NOT FSO.FileExists (pathToFiles & certFile) Then
       MsgBox pathToFiles & certFile & " is missing. Cannot continue.", vbCritical, "Missing File"
       Wscript.Quit
End If
'--Register CAPICOM.DLL
Set WshShell = WScript.CreateObject("WScript.Shell")
Return = WshShell.Run("regsvr32 C:\Windows\System32\capicom.dll /s", 0, true)
 
'Load the certificate file and convert it to Base-64
Set Certificate = CreateObject("CAPICOM.Certificate")
Certificate.Load pathToFiles & certFile
BinaryEncodedCertificate = Certificate.Export(CAPICOM_ENCODE_BINARY)
Set Utilities = CreateObject("CAPICOM.Utilities")
ArrayEncodedCertificate = Utilities.BinaryStringToByteArray(BinaryEncodedCertificate)
 
'Configure connection to Active Directory
Set con = CreateObject("ADODB.Connection")
con.Provider = "ADsDSOObject"
con.Open "DS Query"
Set command = CreateObject("ADODB.Command")
Set command.ActiveConnection = con
command.Properties("searchscope") = 2
command.Properties("Page Size") = 20000
command.Properties("Timeout") = 180
 
'Get default domain
Set oRoot = GetObject("LDAP://rootDSE")
oDomain = "LDAP://" & oRoot.Get("defaultNamingContext")
 
'Construct and execute query to get the eASUsersGroup
command.CommandText = "SELECT AdsPath FROM '" & oDomain & "' WHERE name = '" & eASUsersGroup & "' AND objectClass = 'Group'"
Set rs = Command.Execute
 
'Append to the log file
FullLog.writeline String(75, "=")
FullLog.writeline "Publish Mobile Cert.vbs"
FullLog.writeline Now
FullLog.Writeline "Adding the mobile user certificate to the following users:"
FullLog.writeline String(75, "-")
 
'Loop through the result set
Do While NOT rs.EOF
       Set oGroup = GetObject(rs.fields(0))
       groupDN = oGroup.distinguishedName
       'Publish the certificate to each member of the group
       For Each Member In oGroup.Members
              userCount = userCount + 1
              'Append the certificate to the user's certificate store in Active Directory
              Set UserObj = GetObject("LDAP://" & member.distinguishedName)
              UserObj.PutEx ADS_PROPERTY_APPEND, "userCertificate", Array(ArrayEncodedCertificate)
              UserObj.SetInfo
              If Err.Number = 0 Then
                     FullLog.writeline member.distinguishedName
              Else
                     FullLog.writeline "Unable to update user: " & member.distinguishedName
                     errorCount = errorCount + 1
              End If
       Next
       Exit Do
Loop
 
FullLog.writeline String(75, "=") & vbCRLF & vbCRLF
 
msg = "Successfully published the certificate to " & userCount - errorCount & " user accounts." & vbCRLF
msg = msg & "Review the Publish Mobile Cert.log for details."
If errorCount > 0 Then 
       msg = msg & vbCRLF & vbCRLF & errorCount & " error(s) were encountered."
       MsgBox msg, vbExclamation, "Publish Mobile Cert"
Else
       MsgBox msg, vbInformation, "Publish Mobile Cert"
End If
